@@ -139,6 +139,7 @@ void ListWindow::showNewExercise()
 void ListWindow::showNewProgram()
 {
     npw = new NewProgramWindow(this);
+    npw->load();
     npw->show();
 }
 
@@ -228,6 +229,6 @@ void ListWindow::import()
 {
 
     QString s = QFileDialog::getOpenFileName(this,"Choose a file","/home/user/MyDocs","XML files (*.xml)");
-    //qDebug() << s;
+
     xml->import(s);
 }
