@@ -16,12 +16,17 @@ NewExerciseWindow::NewExerciseWindow(QWidget *parent) :
 
 
     QVBoxLayout *vLayout = new QVBoxLayout();
+
+    QHBoxLayout *txtLayout = new QHBoxLayout();
+
     txtName = new QLineEdit();
     txtName->setPlaceholderText("Name");
     txtMuscle = new QLineEdit();
     txtMuscle->setPlaceholderText("Muscle");
     txtHowTo = new QTextEdit("How to...");
-
+    txtHowTo->setSizePolicy(QSizePolicy::Expanding,QSizePolicy::Expanding);
+    txtLayout->addWidget(txtName);
+    txtLayout->addWidget(txtMuscle);
 
     model = new QStandardItemModel(this);
     model->appendRow(new QStandardItem(tr("Arms")));
@@ -37,14 +42,28 @@ NewExerciseWindow::NewExerciseWindow(QWidget *parent) :
     selectorGroup = new QMaemo5ListPickSelector;
     selectorGroup->setModel(model);
     btnGroup->setPickSelector(selectorGroup);
-
     btnGroup->setValueText("Arms");
+    txtLayout->addWidget(btnGroup);
+
+    btnPic1 = new QMaemo5ValueButton("Start image");
+    connect(btnPic1,SIGNAL(clicked()),this,SLOT(savePic1()));
+    btnPic2 = new QMaemo5ValueButton("End image");
+    connect(btnPic2,SIGNAL(clicked()),this,SLOT(savePic2()));
+
 
     btnSave = new QPushButton("Save");
-    vLayout->addWidget(txtName);
-    vLayout->addWidget(txtMuscle);
-    vLayout->addWidget(btnGroup);
+
+    //vLayout->addWidget(txtName);
+    vLayout->addLayout(txtLayout);
+    //vLayout->addWidget(txtMuscle);
+    //vLayout->addWidget(btnGroup);
     vLayout->addWidget(txtHowTo);
+
+    QHBoxLayout *picLayout = new QHBoxLayout();
+    picLayout->addWidget(btnPic1);
+    picLayout->addWidget(btnPic2);
+    vLayout->addLayout(picLayout);
+
     vLayout->addWidget(btnSave);
 
     setLayout(vLayout);
@@ -53,6 +72,18 @@ NewExerciseWindow::NewExerciseWindow(QWidget *parent) :
     connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged()));
 }
 
+void NewExerciseWindow::savePic1()
+{
+    pic1 = QFileDialog::getOpenFileName(this,"Choose an image","/home/user/MyDocs","PNG files (*.png)");
+    btnPic1->setValueText(pic1);
+}
+
+void NewExerciseWindow::savePic2()
+{
+    pic2 = QFileDialog::getOpenFileName(this,"Choose an image","/home/user/MyDocs","PNG files (*.png)");
+    btnPic2->setValueText(pic2);
+}
+
 void NewExerciseWindow::saveExercise()
 {
 
@@ -76,11 +107,28 @@ void NewExerciseWindow::saveExercise()
     QString group = btnGroup->valueText();
     QString muscle = txtMuscle->text();
     QString info = txtHowTo->toPlainText();
+    QString tmpName;
+    QDir dir;
+
     if(group == "Cardio")
         xml->saveCardio(name);
     else
         xml->saveEx(name,group,muscle,info);
     //if saved OK
+    if(pic1 != "")
+    {
+        tmpName = name;
+        tmpName.replace(" ", "");
+        tmpName.append("1.png");
+        dir.rename(pic1,"/home/user/.qexercise/Images/" + name);
+    }
+    if(pic2 != "")
+    {
+        tmpName = name;
+        tmpName.replace(" ", "");
+        tmpName.append("2.png");
+        dir.rename(pic2,"/home/user/.qexercise/Images/" + name);
+    }
 
     QMaemo5InformationBox::information(this, "Exercise saved.",
                                                 QMaemo5InformationBox::DefaultTimeout);
